@@ -38,17 +38,5 @@ class DebugCommand(PluginCommand):
 
 
         """
-
-        database = Variables(filename="~/.cloudmesh/variables.dat")
-
-        if arguments.on:
-            database["debug"] = True
-            database["trace"] = True
-            database["verbose"] = '10'
-            database["timer"] = True
-
-        elif arguments.off:
-            database["debug"] = False
-            database["trace"] = False
-            database["verbose"] = '0'
-            database["timer"] = False
+        print(args, arguments)
+        self.set_debug(args)
